==> haskell-logging-facade-0.3.1-176.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-logging-facade.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 logging-facade
version:              0.3.1
visibility:           public
id:                   logging-facade-0.3.1-745DHdHdio54Uv4AfVm11n
key:                  logging-facade-0.3.1-745DHdHdio54Uv4AfVm11n
license:              MIT
copyright:            (c) 2014-2021 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
homepage:             https://github.com/sol/logging-facade#readme
synopsis:             Simple logging abstraction that allows multiple back-ends
description:          Simple logging abstraction that allows multiple back-ends
category:             System
abi:                  1229fb3624ea798af6c5ca65a3658db9
exposed:              True
exposed-modules:
    System.Logging.Facade System.Logging.Facade.Class
    System.Logging.Facade.Sink System.Logging.Facade.Types

hidden-modules:       Paths_logging_facade
import-dirs:          /usr/lib/ghc-9.2.8/site-local/logging-facade-0.3.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/logging-facade-0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-logging-facade
hs-libraries:         HSlogging-facade-0.3.1-745DHdHdio54Uv4AfVm11n
depends:
    base-4.16.4.0 call-stack-0.4.0-7Kj6UtaYY94JDoMxAZHX8y
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-logging-facade/html/logging-facade.haddock

haddock-html:         /usr/share/doc/haskell-logging-facade/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-logging-facade-0.3.1-180.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-logging-facade.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 logging-facade
version:              0.3.1
visibility:           public
id:                   logging-facade-0.3.1-2yyh5h7hrTe4FiOaTIf7vH
key:                  logging-facade-0.3.1-2yyh5h7hrTe4FiOaTIf7vH
license:              MIT
copyright:            (c) 2014-2021 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
homepage:             https://github.com/sol/logging-facade#readme
synopsis:             Simple logging abstraction that allows multiple back-ends
description:          Simple logging abstraction that allows multiple back-ends
category:             System
abi:                  f1ed916dc5fce563f88f39854f20e895
exposed:              True
exposed-modules:
    System.Logging.Facade System.Logging.Facade.Class
    System.Logging.Facade.Sink System.Logging.Facade.Types

hidden-modules:       Paths_logging_facade
import-dirs:          /usr/lib/ghc-9.2.8/site-local/logging-facade-0.3.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/logging-facade-0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-logging-facade
hs-libraries:         HSlogging-facade-0.3.1-2yyh5h7hrTe4FiOaTIf7vH
depends:
    base-4.16.4.0 call-stack-0.4.0-kYtciisYfe7TdjBJDTvHP
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-logging-facade/html/logging-facade.haddock

haddock-html:         /usr/share/doc/haskell-logging-facade/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
